==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiGui/QBackingStore_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qbackingstore.h>
#include <QtCore/QVariant>
#include <QtGui/qwindow.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qregion.h>
#include <QtCore/qpoint.h>
#include <QtCore/qsize.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QBackingStore(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QBackingStore")
    QBackingStore *_ptr = reinterpret_cast<QBackingStore *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QBackingStore(QWindow*)
void __qt_construct_QBackingStore_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBackingStore(QWindow*)")
    jobject window0 = __java_arguments[0].l;
    QWindow* __qt_window0 = qtjambi_cast<QWindow* >(__jni_env, window0);
    QBackingStore *__qt_this = new(__qtjambi_ptr) QBackingStore(__qt_window0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QBackingStore
void __qt_destruct_QBackingStore(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QBackingStore")
    reinterpret_cast<QBackingStore*>(ptr)->~QBackingStore();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QBackingStore::QBackingStore(QWindow*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_initialize_1native__Lio_qt_gui_QBackingStore_2Lio_qt_gui_QWindow_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject window0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBackingStore::QBackingStore(QWindow*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = window0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBackingStore_0, sizeof(QBackingStore), typeid(QBackingStore), false, &deleter_QBackingStore, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBackingStore::beginPaint(QRegion)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_beginPaint_1native_1cref_1QRegion__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::beginPaint(QRegion)", __qt_this)
        const QRegion& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QRegion>(arg__1);
        __qt_this->beginPaint(__qt_arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBackingStore::endPaint()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_endPaint_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::endPaint()", __qt_this)
        __qt_this->endPaint();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBackingStore::flush(QRegion,QWindow*,QPoint)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_flush_1native_1cref_1QRegion_1QWindow_1ptr_1cref_1QPoint__JJJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID region0,
 QtJambiNativeID window1,
 QtJambiNativeID offset2)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::flush(QRegion,QWindow*,QPoint)", __qt_this)
        const QRegion& __qt_region0 = QtJambiAPI::valueReferenceFromNativeId<QRegion>(region0);
        QWindow* __qt_window1 = QtJambiAPI::objectFromNativeId<QWindow>(window1);
        const QPoint& __qt_offset2 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(offset2);
        __qt_this->flush(__qt_region0, __qt_window1, __qt_offset2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBackingStore::hasStaticContents()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_hasStaticContents_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::hasStaticContents()const", __qt_this)
        __java_return_value = __qt_this->hasStaticContents();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBackingStore::paintDevice()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_paintDevice_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::paintDevice()", __qt_this)
        QPaintDevice* __qt_return_value = __qt_this->paintDevice();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBackingStore::resize(QSize)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_resize_1native_1cref_1QSize__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID size0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::resize(QSize)", __qt_this)
        const QSize& __qt_size0 = QtJambiAPI::valueReferenceFromNativeId<QSize>(size0);
        __qt_this->resize(__qt_size0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBackingStore::scroll(QRegion,int,int)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_scroll_1native_1cref_1QRegion_1int_1int__JJII)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID area0,
 jint dx1,
 jint dy2)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::scroll(QRegion,int,int)", __qt_this)
        const QRegion& __qt_area0 = QtJambiAPI::valueReferenceFromNativeId<QRegion>(area0);
        __java_return_value = __qt_this->scroll(__qt_area0, static_cast<int>(dx1), static_cast<int>(dy2));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBackingStore::setStaticContents(QRegion)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_setStaticContents_1native_1cref_1QRegion__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID region0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::setStaticContents(QRegion)", __qt_this)
        const QRegion& __qt_region0 = QtJambiAPI::valueReferenceFromNativeId<QRegion>(region0);
        __qt_this->setStaticContents(__qt_region0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBackingStore::size()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_size_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::size()const", __qt_this)
        QSize __qt_return_value = __qt_this->size();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBackingStore::staticContents()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_staticContents_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::staticContents()const", __qt_this)
        QRegion __qt_return_value = __qt_this->staticContents();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBackingStore::window()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_window_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::window()const", __qt_this)
        QWindow* __qt_return_value = __qt_this->window();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QBackingStore(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QBackingStore>("QBackingStore", "io/qt/gui/QBackingStore");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QBackingStore, {
        ConstructorInfo(&__qt_construct_QBackingStore_0, "Lio/qt/gui/QWindow;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QBackingStore);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiGui/QBackingStore_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtGui/qbackingstore.h>
#include <QtCore/QVariant>
#include <QtCore/qpoint.h>
#include <QtCore/qsize.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qregion.h>
#include <QtGui/qwindow.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QBackingStore(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QBackingStore")
    QBackingStore *_ptr = reinterpret_cast<QBackingStore *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QBackingStore(QWindow*)
void __qt_construct_QBackingStore_QWindow_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBackingStore(QWindow*)")
    jobject window0 = __java_arguments[0].l;
    QWindow* __qt_window0 = qtjambi_cast<QWindow*>(__jni_env, window0);
    QBackingStore *__qt_this = new(__qtjambi_ptr) QBackingStore(__qt_window0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QBackingStore::QBackingStore(QWindow*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_initialize_1native__Lio_qt_gui_QBackingStore_2Lio_qt_gui_QWindow_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject window0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBackingStore::QBackingStore(QWindow*)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = window0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBackingStore_QWindow_ptr, sizeof(QBackingStore), typeid(QBackingStore), 0, false, &deleter_QBackingStore, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QBackingStore
void __qt_destruct_QBackingStore(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QBackingStore")
    reinterpret_cast<QBackingStore*>(ptr)->~QBackingStore();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QBackingStore::beginPaint(QRegion)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_beginPaint_1native_1cref_1QRegion__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::beginPaint(QRegion)", __this_nativeId)
        const QRegion& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QRegion>(arg__1);
        __qt_this->beginPaint(__qt_arg__1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBackingStore::endPaint()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_endPaint_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::endPaint()", __this_nativeId)
        __qt_this->endPaint();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBackingStore::flush(QRegion,QWindow*,QPoint)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_flush_1native_1cref_1QRegion_1QWindow_1ptr_1cref_1QPoint__JJJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID region0,
 QtJambiNativeID window1,
 QtJambiNativeID offset2)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::flush(QRegion,QWindow*,QPoint)", __this_nativeId)
        const QRegion& __qt_region0 = QtJambiAPI::valueReferenceFromNativeId<QRegion>(region0);
        QWindow* __qt_window1 = QtJambiAPI::objectFromNativeId<QWindow>(window1);
        const QPoint& __qt_offset2 = QtJambiAPI::valueReferenceFromNativeId<QPoint>(offset2);
        __qt_this->flush(__qt_region0, __qt_window1, __qt_offset2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBackingStore::hasStaticContents()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_hasStaticContents_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::hasStaticContents()const", __this_nativeId)
        __java_return_value = __qt_this->hasStaticContents();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBackingStore::paintDevice()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_paintDevice_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::paintDevice()", __this_nativeId)
        QPaintDevice* __qt_return_value = __qt_this->paintDevice();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBackingStore::resize(QSize)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_resize_1native_1cref_1QSize__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID size0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::resize(QSize)", __this_nativeId)
        const QSize& __qt_size0 = QtJambiAPI::valueReferenceFromNativeId<QSize>(size0);
        __qt_this->resize(__qt_size0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBackingStore::scroll(QRegion,int,int)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_scroll_1native_1cref_1QRegion_1int_1int__JJII)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID area0,
 jint dx1,
 jint dy2)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::scroll(QRegion,int,int)", __this_nativeId)
        const QRegion& __qt_area0 = QtJambiAPI::valueReferenceFromNativeId<QRegion>(area0);
        __java_return_value = __qt_this->scroll(__qt_area0, static_cast<int>(dx1), static_cast<int>(dy2));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBackingStore::setStaticContents(QRegion)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_setStaticContents_1native_1cref_1QRegion__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID region0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::setStaticContents(QRegion)", __this_nativeId)
        const QRegion& __qt_region0 = QtJambiAPI::valueReferenceFromNativeId<QRegion>(region0);
        __qt_this->setStaticContents(__qt_region0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBackingStore::size()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_size_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::size()const", __this_nativeId)
        QSize __qt_return_value = __qt_this->size();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBackingStore::staticContents()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_staticContents_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::staticContents()const", __this_nativeId)
        QRegion __qt_return_value = __qt_this->staticContents();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBackingStore::window()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QBackingStore_window_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QBackingStore *__qt_this = QtJambiAPI::objectFromNativeId<QBackingStore>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBackingStore::window()const", __this_nativeId)
        QWindow* __qt_return_value = __qt_this->window();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QBackingStore(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QBackingStore>("QBackingStore", "io/qt/gui/QBackingStore");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QBackingStore, {
        ConstructorInfo(&__qt_construct_QBackingStore_QWindow_ptr, "Lio/qt/gui/QWindow;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QBackingStore);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
